==> TauP-3.1.1-SNAPSHOT.tgz: TauP-3.1.1-SNAPSHOT/src/main/java/edu/sc/seis/TauP/JSONLabels.java <==
package edu.sc.seis.TauP;

public interface JSONLabels {
    String DISTDEG_LABEL = "distdeg";
    String SOURCEDEPTH_LIST = "sourcedepthlist";
    String RECEIVERDEPTH_LIST = "receiverdepthlist";
    String SOURCEDEPTH = "sourcedepth";
    String RECEIVERDEPTH = "receiverdepth";
    String PHASE_LIST = "phases";
    String PHASE = "phase";
    String TIME = "time";
    String RAYPARAM = "rayparam";
    String TAKEOFF = "takeoff";
    String INCIDENT = "incident";
    String PURISTDIST = "puristdist";
    String PURISTNAME = "puristname";
    String DESC = "desc";
    String AMP = "amp";
    String FACTORPSV = "factorpsv";
    String FACTORSH = "factorsh";
    String GEOSPREAD = "geospread";
    String ATTENUATION = "attenuation";
    String FREE_FACTOR = "freeFactor";
    String MOMENT = "moment";
    String RADIATION_PATTERN = "radiationPattern";
    String RADIATION_TERM = "radiationTerm";
    String UNITCONV = "unitconv";
    String ERROR = "error";
    String REFLTRANPSV = "refltranpsv";
    String REFLTRANSH = "refltransh";
    String DEPTH = "depth";
    String SCATTER = "scatter";
    String SCATTERER = "scatterer";
    String RELATIVE = "relative";
    String DIFFERENCE = "difference";
    String ARRIVAL_LIST = "arrivals";
    String ARRIVAL = "arrival";
    String PIERCE = "pierce";
    String PATHLENGTH = "pathlength";
    String PATH = "path";
    String SOURCE = "source";
    String RECEIVER = "receiver";
    String LABEL = "label";
    String DESCRIPTION = "description";
    String X_AXIS = "x";
    String Y_AXIS = "y";
    String SEGMENTS = "segments";
    String MODEL = "model";
    String MW = "Mw";
    String ATTEN_FREQ = "attenuationfreq";
    String FAULT = "fault";
    String STRIKE = "strike";
    String DIP = "dip";
    String RAKE = "rake";

    String DESCRIPTIONS = "descriptions";

    String SHADOW_PRE_ARRIVAL = "preshadow";
    String SHADOW_POST_ARRIVAL = "postshadow";

    String NL = "\n";
    String TOP_DEPTH = "topdepth";
    String BOT_DEPTH = "botdepth";
    String CURVES = "curves";

    String CALCTYPE = "calctype";
    String INVFLATTENING = "invflattening";
    String SOURCE_LIST = "sources";
    String RECEIVER_LIST = "receivers";
    String LAT = "lat";
    String LON = "lon";
    String DEG = "deg";
    String KM = "km";
    String AZ = "az";
    String BAZ = "baz";
    String FROM = "from";
    String TO = "to";
    String DISTANCES = "distances";
    String RADIAN = "radian";
    String POINTS = "points";
    String SEGNAME = "name";
    String WAVETYPE = "wavetype";
    String SEGMENT = "segment";
    String NAME = "name";
    String PREFNAME = "preferredname";
    String ISBACKSCATTER = "isbackscatter";
    String PWAVE = "pwave";
    String SWAVE = "swave";
    String UP = "up";
    String DOWN = "down";
    String FLAT = "flat";
    String TIMESTEPS = "timesteps";
    String ISOCHRON = "isochrons";
    String WAVEFRONT = "wavefronts";
    String MODEL_LIST = "models";
}

==> TauP-3.2.0-SNAPSHOT.tgz: TauP-3.2.0-SNAPSHOT/src/main/java/edu/sc/seis/TauP/JSONLabels.java <==
package edu.sc.seis.TauP;

public interface JSONLabels {
    String DISTDEG_LABEL = "distdeg";
    String SOURCEDEPTH_LIST = "sourcedepthlist";
    String RECEIVERDEPTH_LIST = "receiverdepthlist";
    String SOURCEDEPTH = "sourcedepth";
    String RECEIVERDEPTH = "receiverdepth";
    String PHASE_LIST = "phases";
    String PHASE = "phase";
    String TIME = "time";
    String RAYPARAM = "rayparam";
    String TAKEOFF = "takeoff";
    String INCIDENT = "incident";
    String PURISTDIST = "puristdist";
    String PURISTNAME = "puristname";
    String DESC = "desc";
    String AMP = "amp";
    String FACTORPSV = "factorpsv";
    String FACTORSH = "factorsh";
    String GEOSPREAD = "geospread";
    String ATTENUATION = "attenuation";
    String FREE_FACTOR = "freeFactor";
    String MOMENT = "moment";
    String RADIATION_PATTERN = "radiationPattern";
    String RADIATION_TERM = "radiationTerm";
    String UNITCONV = "unitconv";
    String ERROR = "error";
    String REFLTRANPSV = "refltranpsv";
    String REFLTRANSH = "refltransh";
    String DEPTH = "depth";
    String SCATTER = "scatter";
    String SCATTERER = "scatterer";
    String RELATIVE = "relative";
    String DIFFERENCE = "difference";
    String ARRIVAL_LIST = "arrivals";
    String ARRIVAL = "arrival";
    String PIERCE = "pierce";
    String PATHLENGTH = "pathlength";
    String PATH = "path";
    String SOURCE = "source";
    String RECEIVER = "receiver";
    String LABEL = "label";
    String DESCRIPTION = "description";
    String X_AXIS = "x";
    String Y_AXIS = "y";
    String SEGMENTS = "segments";
    String MODEL = "model";
    String MW = "Mw";
    String ATTEN_FREQ = "attenuationfreq";
    String ATTEN_NUM_FREQ = "attenuationnumfreq";
    String FAULT = "fault";
    String STRIKE = "strike";
    String DIP = "dip";
    String RAKE = "rake";

    String DESCRIPTIONS = "descriptions";

    String SHADOW_PRE_ARRIVAL = "preshadow";
    String SHADOW_POST_ARRIVAL = "postshadow";

    String NL = "\n";
    String TOP_DEPTH = "topdepth";
    String BOT_DEPTH = "botdepth";
    String CURVES = "curves";

    String CALCTYPE = "calctype";
    String INVFLATTENING = "invflattening";
    String SOURCE_LIST = "sources";
    String RECEIVER_LIST = "receivers";
    String LAT = "lat";
    String LON = "lon";
    String DEG = "deg";
    String KM = "km";
    String AZ = "az";
    String BAZ = "baz";
    String FROM = "from";
    String TO = "to";
    String DISTANCES = "distances";
    String RADIAN = "radian";
    String POINTS = "points";
    String SEGNAME = "name";
    String WAVETYPE = "wavetype";
    String SEGMENT = "segment";
    String NAME = "name";
    String PREFNAME = "preferredname";
    String ISBACKSCATTER = "isbackscatter";
    String PWAVE = "pwave";
    String SWAVE = "swave";
    String UP = "up";
    String DOWN = "down";
    String FLAT = "flat";
    String TIMESTEPS = "timesteps";
    String ISOCHRON = "isochrons";
    String WAVEFRONT = "wavefronts";
    String MODEL_LIST = "models";
    String RAYCALC = "raytype";
    String SOURCE_LOC = "sourceloc";
    String RECEIVER_LOC = "receiverloc";
    String UNIT = "unit";
    String INDEX = "index";
    String DIST = "dist";
    String EXACT = "exact";
    String HEMISPHERE = "hemisphere";

    String VP = "Vp";
    String VS = "Vs";
    String QP = "Qp";
    String QS = "Qs";
    String DENSITY = "density";
    String SLOWP = "slowness_p";
    String SLOWS = "slowness_s";
    String ABOVE = "above";
    String BELOW = "below";
    String DERIVATIVE = "derivative";
    String DPDDEG = "dp/ddeg";
    String VELOCITY = "velocity";
    String RADIALSLOWNESS = "radialslowness";
    String RADIUS = "radius";
}
